@@ -14,7 +14,10 @@ extern "C" {
 
 extern void * di_realloc (void *, Size_t);
 extern void di_trimchar (char *, int);
+char * di_strtok (char *str, const char *delim, char **tokstr);
+# if ! _lib_stpecpy
 char * stpecpy (char *dst, char *end, const char *src);
+# endif
 
 # if ! _lib_strdup
 extern char * strdup (const char *);
